<template>
  <span class="flex h-2 w-2 absolute -top-0.5 -right-0.5">
    <span class="animate-ping absolute inline-flex h-full w-full rounded-full bg-red-400 opacity-75"></span>
    <span class="relative inline-flex rounded-full h-2 w-2 bg-red-500"></span>
  </span>
</template>