<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Error - {{ data.exception.message }}</title>
    <style>
      {% include "exceptionite.css" %}
    </style>
  </head>

  <body class="h-screen w-full">
    <div id="app" class="min-h-screen"></div>
    <script>
    {{ script }}
    </script>
    <script>
      window.data = {{ data | tojson | safe }}
    </script>
    <script>
      window.Exceptionite = window.exceptionite(window.data);
    </script>
    <script>
      Exceptionite.start();
    </script>
  </body>
</html>