<template>
  <div class="bg-white dark:bg-gray-800 dark:text-gray-300 rounded-md p-2 w-full mb-4 shadow-md">
    <span style="text-decoration: underline">
        <a target="_blank" href="https://github.com/sponsors/MasoniteFramework">❤️ Find this page useful? Support Masonite so we can continue to build great free tools like this one!</a>
    </span>
  </div>
</template>